pub enum AdbProxyMode {
None,
WakeContainer,
}Variants
None
Don’t proxy events at all.
WakeContainer
Have the Starnix runner proxy events such that the container will wake up if events are received while the container is suspended.